
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.010.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "modules for the L<VKC Arthub|>",
  "dist_author" => [
    "Matthias Vandermaesen <matthias.vandermaesen\@vlaamsekunstcollectie.be>"
  ],
  "dist_name" => "Datahub-Factory-Arthub",
  "dist_version" => "0.98",
  "license" => "gpl",
  "module_name" => "Datahub::Factory::Arthub",
  "recursive_test_files" => 1,
  "requires" => {
    "Authen::NTLM" => 0,
    "Catmandu" => 0,
    "Catmandu::AAT" => 0,
    "Catmandu::Adlib" => 0,
    "Catmandu::Importer::DBI" => 0,
    "Catmandu::Importer::OAI" => 0,
    "Catmandu::Store::DBI" => 0,
    "Catmandu::VIAF" => 0,
    "Config::Simple" => 0,
    "DBD::SQLite" => 0,
    "DBD::mysql" => 0,
    "DBI" => 0,
    "Datahub::Factory" => "1.70",
    "LWP::Protocol::https" => 0,
    "LWP::UserAgent" => 0,
    "Lido::XML" => 0,
    "Moo" => 0,
    "Try::Tiny" => 0,
    "URI::Split" => 0,
    "WebService::Rackspace::CloudFiles" => 0,
    "namespace::clean" => 0,
    "perl" => "5.008005"
  },
  "test_requires" => {
    "Test::More" => "0.96"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::More" => "0.96"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
